@@ -1,18 +1,15 @@
 from __future__ import absolute_import
-# Copyright (c) 2010-2016 openpyxl
+# Copyright (c) 2010-2017 openpyxl
 
 from openpyxl.descriptors import Bool
-
-from .hashable import HashableObject
+from openpyxl.descriptors.serialisable import Serialisable
 
 
-class Protection(HashableObject):
+class Protection(Serialisable):
     """Protection options for use in styles."""
 
     tagname = "protection"
 
-    __fields__ = ('locked',
-                  'hidden')
     locked = Bool()
     hidden = Bool()
 
