@@ -9,6 +9,7 @@ import re
 from zipfile import ZipFile, ZIP_DEFLATED
 
 # package imports
+from openpyxl.utils.exceptions import InvalidFileException
 from openpyxl.xml.constants import (
     ARC_SHARED_STRINGS,
     ARC_CONTENT_TYPES,
@@ -117,13 +118,13 @@ class ExcelWriter(object):
     def _write_images(self):
         # delegate to object
         for img in self._images:
-            buf = BytesIO()
-            img.image.save(buf, format='PNG')
-            self._archive.writestr(img.path[1:], buf.getvalue())
+            self._archive.writestr(img.path[1:], img._data())
 
 
     def _write_charts(self):
         # delegate to object
+        if len(self._charts) != len(set(self._charts)):
+            raise InvalidFileException("The same chart cannot be used in more than one worksheet")
         for chart in self._charts:
             self._archive.writestr(chart.path[1:], tostring(chart._write()))
             self.manifest.append(chart)
