@@ -1,5 +1,5 @@
 from __future__ import absolute_import
-# Copyright (c) 2010-2016 openpyxl
+# Copyright (c) 2010-2017 openpyxl
 
 """Write the workbook global settings to the archive."""
 
@@ -87,6 +87,9 @@ def write_workbook(workbook):
         props.date1904 = True
     root.workbookPr = props
 
+    # workbook protection
+    root.workbookProtection = wb.security
+
     # book views
     active = get_active_sheet(wb)
     view = BookView(activeTab=active)
